<?php

namespace Drupal\twig_hash\TwigExtension;

/**
 * Twig extension to hash an input string.
 */
class TwigHash extends \Twig_Extension {
  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return [
      new \Twig_SimpleFilter('hash', array($this, 'hashFilter')),
      new \Twig_SimpleFilter('baseConv', array($this, 'baseConvFilter')),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions() {
    return array(
      new \Twig_SimpleFunction('uuid', array($this, 'getUuid')),
    );
  }

  /**
   * Gets a unique identifier for this Twig extension.
   */
  public function getName() {
    return 'twig_hash.twig_extension';
  }

  /**
   * Returns the hashed version of a variable.
   *
   * @param string $string
   *   A string containing the text to be MD5'd.
   *
   * @return string
   *   An MD5'd version of the input string.
   */
  public static function hashFilter($string, $hash_type = "md5") {
    if (!in_array($hash_type, hash_algos())) {
      return "Invalid hash algorithm";
    }
    return hash($hash_type, $string);
  }

  /**
   * Returns a variable converted to an alternative base.
   *
   * @param string $string
   *   A string containing the text to be base converted.
   *
   * @return string
   *   An base converted version of the input string.
   */
  public static function baseConvFilter($string, $from = 10, $to = 16) {
    return base_convert($string, $from, $to);
  }

  /**
   * Returns a unique id.
   *
   * @return string
   *   A unique id.
   */
  public static function getUuid() {
    return uniqid();
  }

}
